/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQt3DRender.h"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 37 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAbstractTexture.cpp"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 65 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAbstractTexture.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderimage.sip"
#include <qshaderimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogram.sip"
#include <qshaderprogram.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogrambuilder.sip"
#include <qshaderprogrambuilder.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsortpolicy.sip"
#include <qsortpolicy.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qspotlight.sip"
#include <qspotlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstencilmask.sip"
#include <qstencilmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperation.sip"
#include <qstenciloperation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperationarguments.sip"
#include <qstenciloperationarguments.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltest.sip"
#include <qstenciltest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltestarguments.sip"
#include <qstenciltestarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsubtreeenabler.sip"
#include <qsubtreeenabler.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechnique.sip"
#include <qtechnique.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechniquefilter.sip"
#include <qtechniquefilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexture.sip"
#include <qtexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturedata.sip"
#include <qtexturedata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturedataupdate.sip"
#include <qtexturedataupdate.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturedataupdate.sip"
#include <qtexturedataupdate.h>
#line 264 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAbstractTexture.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 267 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAbstractTexture.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 270 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAbstractTexture.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynodeaddedchange.sip"
#include <qpropertynodeaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynoderemovedchange.sip"
#include <qpropertynoderemovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchange.sip"
#include <qpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchangebase.sip"
#include <qpropertyupdatedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchange.sip"
#include <qpropertyvalueaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchangebase.sip"
#include <qpropertyvalueaddedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchange.sip"
#include <qpropertyvalueremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchangebase.sip"
#include <qpropertyvalueremovedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 53 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 323 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAbstractTexture.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 326 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAbstractTexture.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderimage.sip"
#include <qshaderimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogram.sip"
#include <qshaderprogram.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogrambuilder.sip"
#include <qshaderprogrambuilder.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsortpolicy.sip"
#include <qsortpolicy.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qspotlight.sip"
#include <qspotlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstencilmask.sip"
#include <qstencilmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperation.sip"
#include <qstenciloperation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperationarguments.sip"
#include <qstenciloperationarguments.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltest.sip"
#include <qstenciltest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltestarguments.sip"
#include <qstenciltestarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsubtreeenabler.sip"
#include <qsubtreeenabler.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechnique.sip"
#include <qtechnique.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechniquefilter.sip"
#include <qtechniquefilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexture.sip"
#include <qtexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturedata.sip"
#include <qtexturedata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturedataupdate.sip"
#include <qtexturedataupdate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturegenerator.sip"
#include <qtexturegenerator.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturegenerator.sip"
#include <qtexturegenerator.h>
#line 527 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAbstractTexture.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderimage.sip"
#include <qshaderimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogram.sip"
#include <qshaderprogram.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogrambuilder.sip"
#include <qshaderprogrambuilder.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsortpolicy.sip"
#include <qsortpolicy.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qspotlight.sip"
#include <qspotlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstencilmask.sip"
#include <qstencilmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperation.sip"
#include <qstenciloperation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperationarguments.sip"
#include <qstenciloperationarguments.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltest.sip"
#include <qstenciltest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltestarguments.sip"
#include <qstenciltestarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsubtreeenabler.sip"
#include <qsubtreeenabler.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechnique.sip"
#include <qtechnique.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechniquefilter.sip"
#include <qtechniquefilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexture.sip"
#include <qtexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturedata.sip"
#include <qtexturedata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturedataupdate.sip"
#include <qtexturedataupdate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturegenerator.sip"
#include <qtexturegenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtextureimage.sip"
#include <qtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtextureimagedata.sip"
#include <qtextureimagedata.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtextureimagedatagenerator.sip"
#include <qtextureimagedatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturewrapmode.sip"
#include <qtexturewrapmode.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturewrapmode.sip"
#include <qtexturewrapmode.h>
#line 736 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAbstractTexture.cpp"
#line 139 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 739 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAbstractTexture.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 752 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAbstractTexture.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 755 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAbstractTexture.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 784 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAbstractTexture.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 787 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAbstractTexture.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 790 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAbstractTexture.cpp"
#line 139 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 793 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAbstractTexture.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 828 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAbstractTexture.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 833 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAbstractTexture.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 836 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAbstractTexture.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 839 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAbstractTexture.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 842 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAbstractTexture.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 845 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAbstractTexture.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 848 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAbstractTexture.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 851 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAbstractTexture.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 854 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAbstractTexture.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 857 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAbstractTexture.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 860 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAbstractTexture.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 863 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAbstractTexture.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 866 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAbstractTexture.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 869 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAbstractTexture.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 872 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAbstractTexture.cpp"


class sipQt3DRender_QAbstractTexture : public ::Qt3DRender::QAbstractTexture
{
public:
    sipQt3DRender_QAbstractTexture(::Qt3DCore::QNode*);
    sipQt3DRender_QAbstractTexture(::Qt3DRender::QAbstractTexture::Target, ::Qt3DCore::QNode*);
    virtual ~sipQt3DRender_QAbstractTexture();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    void sceneChangeEvent(const ::Qt3DCore::QSceneChangePtr&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQt3DRender_QAbstractTexture(const sipQt3DRender_QAbstractTexture &);
    sipQt3DRender_QAbstractTexture &operator = (const sipQt3DRender_QAbstractTexture &);

    char sipPyMethods[8];
};

sipQt3DRender_QAbstractTexture::sipQt3DRender_QAbstractTexture(::Qt3DCore::QNode*a0): ::Qt3DRender::QAbstractTexture(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQt3DRender_QAbstractTexture::sipQt3DRender_QAbstractTexture(::Qt3DRender::QAbstractTexture::Target a0, ::Qt3DCore::QNode*a1): ::Qt3DRender::QAbstractTexture(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQt3DRender_QAbstractTexture::~sipQt3DRender_QAbstractTexture()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQt3DRender_QAbstractTexture::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_Qt3DRender_qt_metaobject(sipPySelf, sipType_Qt3DRender_QAbstractTexture);

    return ::Qt3DRender::QAbstractTexture::metaObject();
}

int sipQt3DRender_QAbstractTexture::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::Qt3DRender::QAbstractTexture::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_Qt3DRender_qt_metacall(sipPySelf, sipType_Qt3DRender_QAbstractTexture, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQt3DRender_QAbstractTexture::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_Qt3DRender_qt_metacast(sipPySelf, sipType_Qt3DRender_QAbstractTexture, _clname, &sipCpp) ? sipCpp : ::Qt3DRender::QAbstractTexture::qt_metacast(_clname));
}

void sipQt3DRender_QAbstractTexture::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::Qt3DRender::QAbstractTexture::disconnectNotify(a0);
        return;
    }

    extern void sipVH_Qt3DRender_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_Qt3DRender_1(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DRender_QAbstractTexture::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::Qt3DRender::QAbstractTexture::connectNotify(a0);
        return;
    }

    extern void sipVH_Qt3DRender_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_Qt3DRender_1(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DRender_QAbstractTexture::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::Qt3DRender::QAbstractTexture::customEvent(a0);
        return;
    }

    extern void sipVH_Qt3DRender_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_Qt3DRender_2(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DRender_QAbstractTexture::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::Qt3DRender::QAbstractTexture::childEvent(a0);
        return;
    }

    extern void sipVH_Qt3DRender_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_Qt3DRender_3(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DRender_QAbstractTexture::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::Qt3DRender::QAbstractTexture::timerEvent(a0);
        return;
    }

    extern void sipVH_Qt3DRender_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_Qt3DRender_4(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQt3DRender_QAbstractTexture::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::Qt3DRender::QAbstractTexture::eventFilter(a0, a1);

    extern bool sipVH_Qt3DRender_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_Qt3DRender_5(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQt3DRender_QAbstractTexture::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::Qt3DRender::QAbstractTexture::event(a0);

    extern bool sipVH_Qt3DRender_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_Qt3DRender_6(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DRender_QAbstractTexture::sceneChangeEvent(const ::Qt3DCore::QSceneChangePtr& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_sceneChangeEvent);

    if (!sipMeth)
    {
        ::Qt3DRender::QAbstractTexture::sceneChangeEvent(a0);
        return;
    }

    extern void sipVH_Qt3DRender_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::Qt3DCore::QSceneChangePtr&);

    sipVH_Qt3DRender_7(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_Qt3DRender_QAbstractTexture_target, "target(self) -> QAbstractTexture.Target");

extern "C" {static PyObject *meth_Qt3DRender_QAbstractTexture_target(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAbstractTexture_target(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QAbstractTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QAbstractTexture, &sipCpp))
        {
            ::Qt3DRender::QAbstractTexture::Target sipRes;

            sipRes = sipCpp->target();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QAbstractTexture_Target);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractTexture, sipName_target, doc_Qt3DRender_QAbstractTexture_target);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAbstractTexture_format, "format(self) -> QAbstractTexture.TextureFormat");

extern "C" {static PyObject *meth_Qt3DRender_QAbstractTexture_format(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAbstractTexture_format(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QAbstractTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QAbstractTexture, &sipCpp))
        {
            ::Qt3DRender::QAbstractTexture::TextureFormat sipRes;

            sipRes = sipCpp->format();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QAbstractTexture_TextureFormat);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractTexture, sipName_format, doc_Qt3DRender_QAbstractTexture_format);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAbstractTexture_generateMipMaps, "generateMipMaps(self) -> bool");

extern "C" {static PyObject *meth_Qt3DRender_QAbstractTexture_generateMipMaps(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAbstractTexture_generateMipMaps(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QAbstractTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QAbstractTexture, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->generateMipMaps();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractTexture, sipName_generateMipMaps, doc_Qt3DRender_QAbstractTexture_generateMipMaps);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAbstractTexture_status, "status(self) -> QAbstractTexture.Status");

extern "C" {static PyObject *meth_Qt3DRender_QAbstractTexture_status(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAbstractTexture_status(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QAbstractTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QAbstractTexture, &sipCpp))
        {
            ::Qt3DRender::QAbstractTexture::Status sipRes;

            sipRes = sipCpp->status();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QAbstractTexture_Status);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractTexture, sipName_status, doc_Qt3DRender_QAbstractTexture_status);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAbstractTexture_addTextureImage, "addTextureImage(self, textureImage: QAbstractTextureImage|None)");

extern "C" {static PyObject *meth_Qt3DRender_QAbstractTexture_addTextureImage(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAbstractTexture_addTextureImage(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QAbstractTextureImage* a0;
        PyObject *a0Wrapper;
        ::Qt3DRender::QAbstractTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B@J8", &sipSelf, sipType_Qt3DRender_QAbstractTexture, &sipCpp, &a0Wrapper, sipType_Qt3DRender_QAbstractTextureImage, &a0))
        {
#line 215 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
            // This takes ownership only if it doesn't already have a parent.
            if (!a0->parent())
                sipTransferTo(a0Wrapper, sipSelf);
            
            sipCpp->addTextureImage(a0);
#line 1217 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAbstractTexture.cpp"

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractTexture, sipName_addTextureImage, doc_Qt3DRender_QAbstractTexture_addTextureImage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAbstractTexture_removeTextureImage, "removeTextureImage(self, textureImage: QAbstractTextureImage|None)");

extern "C" {static PyObject *meth_Qt3DRender_QAbstractTexture_removeTextureImage(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAbstractTexture_removeTextureImage(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QAbstractTextureImage* a0;
        ::Qt3DRender::QAbstractTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_Qt3DRender_QAbstractTexture, &sipCpp, sipType_Qt3DRender_QAbstractTextureImage, &a0))
        {
            sipCpp->removeTextureImage(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractTexture, sipName_removeTextureImage, doc_Qt3DRender_QAbstractTexture_removeTextureImage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAbstractTexture_textureImages, "textureImages(self) -> list[QAbstractTextureImage]");

extern "C" {static PyObject *meth_Qt3DRender_QAbstractTexture_textureImages(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAbstractTexture_textureImages(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QAbstractTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QAbstractTexture, &sipCpp))
        {
            QVector< ::Qt3DRender::QAbstractTextureImage*>*sipRes;

            sipRes = new QVector< ::Qt3DRender::QAbstractTextureImage*>(sipCpp->textureImages());

            return sipConvertFromNewType(sipRes, sipType_QVector_0101Qt3DRender_QAbstractTextureImage, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractTexture, sipName_textureImages, doc_Qt3DRender_QAbstractTexture_textureImages);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAbstractTexture_setWrapMode, "setWrapMode(self, wrapMode: QTextureWrapMode)");

extern "C" {static PyObject *meth_Qt3DRender_QAbstractTexture_setWrapMode(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAbstractTexture_setWrapMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QTextureWrapMode* a0;
        ::Qt3DRender::QAbstractTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_Qt3DRender_QAbstractTexture, &sipCpp, sipType_Qt3DRender_QTextureWrapMode, &a0))
        {
            sipCpp->setWrapMode(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractTexture, sipName_setWrapMode, doc_Qt3DRender_QAbstractTexture_setWrapMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAbstractTexture_wrapMode, "wrapMode(self) -> QTextureWrapMode|None");

extern "C" {static PyObject *meth_Qt3DRender_QAbstractTexture_wrapMode(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAbstractTexture_wrapMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QAbstractTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QAbstractTexture, &sipCpp))
        {
            ::Qt3DRender::QTextureWrapMode*sipRes;

            sipRes = sipCpp->wrapMode();

            return sipConvertFromType(sipRes, sipType_Qt3DRender_QTextureWrapMode, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractTexture, sipName_wrapMode, doc_Qt3DRender_QAbstractTexture_wrapMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAbstractTexture_setSize, "setSize(self, width: int, height: int = 1, depth: int = 1)");

extern "C" {static PyObject *meth_Qt3DRender_QAbstractTexture_setSize(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAbstractTexture_setSize(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1 = 1;
        int a2 = 1;
        ::Qt3DRender::QAbstractTexture *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_height,
            sipName_depth,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bi|ii", &sipSelf, sipType_Qt3DRender_QAbstractTexture, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->setSize(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractTexture, sipName_setSize, doc_Qt3DRender_QAbstractTexture_setSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAbstractTexture_minificationFilter, "minificationFilter(self) -> QAbstractTexture.Filter");

extern "C" {static PyObject *meth_Qt3DRender_QAbstractTexture_minificationFilter(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAbstractTexture_minificationFilter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QAbstractTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QAbstractTexture, &sipCpp))
        {
            ::Qt3DRender::QAbstractTexture::Filter sipRes;

            sipRes = sipCpp->minificationFilter();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QAbstractTexture_Filter);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractTexture, sipName_minificationFilter, doc_Qt3DRender_QAbstractTexture_minificationFilter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAbstractTexture_magnificationFilter, "magnificationFilter(self) -> QAbstractTexture.Filter");

extern "C" {static PyObject *meth_Qt3DRender_QAbstractTexture_magnificationFilter(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAbstractTexture_magnificationFilter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QAbstractTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QAbstractTexture, &sipCpp))
        {
            ::Qt3DRender::QAbstractTexture::Filter sipRes;

            sipRes = sipCpp->magnificationFilter();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QAbstractTexture_Filter);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractTexture, sipName_magnificationFilter, doc_Qt3DRender_QAbstractTexture_magnificationFilter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAbstractTexture_maximumAnisotropy, "maximumAnisotropy(self) -> float");

extern "C" {static PyObject *meth_Qt3DRender_QAbstractTexture_maximumAnisotropy(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAbstractTexture_maximumAnisotropy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QAbstractTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QAbstractTexture, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->maximumAnisotropy();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractTexture, sipName_maximumAnisotropy, doc_Qt3DRender_QAbstractTexture_maximumAnisotropy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAbstractTexture_comparisonFunction, "comparisonFunction(self) -> QAbstractTexture.ComparisonFunction");

extern "C" {static PyObject *meth_Qt3DRender_QAbstractTexture_comparisonFunction(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAbstractTexture_comparisonFunction(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QAbstractTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QAbstractTexture, &sipCpp))
        {
            ::Qt3DRender::QAbstractTexture::ComparisonFunction sipRes;

            sipRes = sipCpp->comparisonFunction();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QAbstractTexture_ComparisonFunction);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractTexture, sipName_comparisonFunction, doc_Qt3DRender_QAbstractTexture_comparisonFunction);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAbstractTexture_comparisonMode, "comparisonMode(self) -> QAbstractTexture.ComparisonMode");

extern "C" {static PyObject *meth_Qt3DRender_QAbstractTexture_comparisonMode(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAbstractTexture_comparisonMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QAbstractTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QAbstractTexture, &sipCpp))
        {
            ::Qt3DRender::QAbstractTexture::ComparisonMode sipRes;

            sipRes = sipCpp->comparisonMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QAbstractTexture_ComparisonMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractTexture, sipName_comparisonMode, doc_Qt3DRender_QAbstractTexture_comparisonMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAbstractTexture_width, "width(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QAbstractTexture_width(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAbstractTexture_width(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QAbstractTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QAbstractTexture, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->width();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractTexture, sipName_width, doc_Qt3DRender_QAbstractTexture_width);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAbstractTexture_height, "height(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QAbstractTexture_height(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAbstractTexture_height(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QAbstractTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QAbstractTexture, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->height();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractTexture, sipName_height, doc_Qt3DRender_QAbstractTexture_height);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAbstractTexture_depth, "depth(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QAbstractTexture_depth(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAbstractTexture_depth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QAbstractTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QAbstractTexture, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->depth();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractTexture, sipName_depth, doc_Qt3DRender_QAbstractTexture_depth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAbstractTexture_layers, "layers(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QAbstractTexture_layers(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAbstractTexture_layers(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QAbstractTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QAbstractTexture, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->layers();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractTexture, sipName_layers, doc_Qt3DRender_QAbstractTexture_layers);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAbstractTexture_samples, "samples(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QAbstractTexture_samples(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAbstractTexture_samples(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QAbstractTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QAbstractTexture, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->samples();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractTexture, sipName_samples, doc_Qt3DRender_QAbstractTexture_samples);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAbstractTexture_dataGenerator, "dataGenerator(self) -> QTextureGenerator");

extern "C" {static PyObject *meth_Qt3DRender_QAbstractTexture_dataGenerator(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAbstractTexture_dataGenerator(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QAbstractTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QAbstractTexture, &sipCpp))
        {
            ::Qt3DRender::QTextureGeneratorPtr*sipRes;

            sipRes = new ::Qt3DRender::QTextureGeneratorPtr(sipCpp->dataGenerator());

            return sipConvertFromNewType(sipRes, sipType_QSharedPointer_0100Qt3DRender_QTextureGenerator, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractTexture, sipName_dataGenerator, doc_Qt3DRender_QAbstractTexture_dataGenerator);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAbstractTexture_setFormat, "setFormat(self, format: QAbstractTexture.TextureFormat)");

extern "C" {static PyObject *meth_Qt3DRender_QAbstractTexture_setFormat(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAbstractTexture_setFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QAbstractTexture::TextureFormat a0;
        ::Qt3DRender::QAbstractTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DRender_QAbstractTexture, &sipCpp, sipType_Qt3DRender_QAbstractTexture_TextureFormat, &a0))
        {
            sipCpp->setFormat(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractTexture, sipName_setFormat, doc_Qt3DRender_QAbstractTexture_setFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAbstractTexture_setGenerateMipMaps, "setGenerateMipMaps(self, gen: bool)");

extern "C" {static PyObject *meth_Qt3DRender_QAbstractTexture_setGenerateMipMaps(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAbstractTexture_setGenerateMipMaps(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::Qt3DRender::QAbstractTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_Qt3DRender_QAbstractTexture, &sipCpp, &a0))
        {
            sipCpp->setGenerateMipMaps(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractTexture, sipName_setGenerateMipMaps, doc_Qt3DRender_QAbstractTexture_setGenerateMipMaps);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAbstractTexture_setWidth, "setWidth(self, width: int)");

extern "C" {static PyObject *meth_Qt3DRender_QAbstractTexture_setWidth(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAbstractTexture_setWidth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::Qt3DRender::QAbstractTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_Qt3DRender_QAbstractTexture, &sipCpp, &a0))
        {
            sipCpp->setWidth(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractTexture, sipName_setWidth, doc_Qt3DRender_QAbstractTexture_setWidth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAbstractTexture_setHeight, "setHeight(self, height: int)");

extern "C" {static PyObject *meth_Qt3DRender_QAbstractTexture_setHeight(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAbstractTexture_setHeight(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::Qt3DRender::QAbstractTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_Qt3DRender_QAbstractTexture, &sipCpp, &a0))
        {
            sipCpp->setHeight(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractTexture, sipName_setHeight, doc_Qt3DRender_QAbstractTexture_setHeight);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAbstractTexture_setDepth, "setDepth(self, depth: int)");

extern "C" {static PyObject *meth_Qt3DRender_QAbstractTexture_setDepth(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAbstractTexture_setDepth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::Qt3DRender::QAbstractTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_Qt3DRender_QAbstractTexture, &sipCpp, &a0))
        {
            sipCpp->setDepth(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractTexture, sipName_setDepth, doc_Qt3DRender_QAbstractTexture_setDepth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAbstractTexture_setMinificationFilter, "setMinificationFilter(self, f: QAbstractTexture.Filter)");

extern "C" {static PyObject *meth_Qt3DRender_QAbstractTexture_setMinificationFilter(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAbstractTexture_setMinificationFilter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QAbstractTexture::Filter a0;
        ::Qt3DRender::QAbstractTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DRender_QAbstractTexture, &sipCpp, sipType_Qt3DRender_QAbstractTexture_Filter, &a0))
        {
            sipCpp->setMinificationFilter(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractTexture, sipName_setMinificationFilter, doc_Qt3DRender_QAbstractTexture_setMinificationFilter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAbstractTexture_setMagnificationFilter, "setMagnificationFilter(self, f: QAbstractTexture.Filter)");

extern "C" {static PyObject *meth_Qt3DRender_QAbstractTexture_setMagnificationFilter(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAbstractTexture_setMagnificationFilter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QAbstractTexture::Filter a0;
        ::Qt3DRender::QAbstractTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DRender_QAbstractTexture, &sipCpp, sipType_Qt3DRender_QAbstractTexture_Filter, &a0))
        {
            sipCpp->setMagnificationFilter(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractTexture, sipName_setMagnificationFilter, doc_Qt3DRender_QAbstractTexture_setMagnificationFilter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAbstractTexture_setMaximumAnisotropy, "setMaximumAnisotropy(self, anisotropy: float)");

extern "C" {static PyObject *meth_Qt3DRender_QAbstractTexture_setMaximumAnisotropy(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAbstractTexture_setMaximumAnisotropy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Qt3DRender::QAbstractTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DRender_QAbstractTexture, &sipCpp, &a0))
        {
            sipCpp->setMaximumAnisotropy(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractTexture, sipName_setMaximumAnisotropy, doc_Qt3DRender_QAbstractTexture_setMaximumAnisotropy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAbstractTexture_setComparisonFunction, "setComparisonFunction(self, function: QAbstractTexture.ComparisonFunction)");

extern "C" {static PyObject *meth_Qt3DRender_QAbstractTexture_setComparisonFunction(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAbstractTexture_setComparisonFunction(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QAbstractTexture::ComparisonFunction a0;
        ::Qt3DRender::QAbstractTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DRender_QAbstractTexture, &sipCpp, sipType_Qt3DRender_QAbstractTexture_ComparisonFunction, &a0))
        {
            sipCpp->setComparisonFunction(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractTexture, sipName_setComparisonFunction, doc_Qt3DRender_QAbstractTexture_setComparisonFunction);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAbstractTexture_setComparisonMode, "setComparisonMode(self, mode: QAbstractTexture.ComparisonMode)");

extern "C" {static PyObject *meth_Qt3DRender_QAbstractTexture_setComparisonMode(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAbstractTexture_setComparisonMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QAbstractTexture::ComparisonMode a0;
        ::Qt3DRender::QAbstractTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DRender_QAbstractTexture, &sipCpp, sipType_Qt3DRender_QAbstractTexture_ComparisonMode, &a0))
        {
            sipCpp->setComparisonMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractTexture, sipName_setComparisonMode, doc_Qt3DRender_QAbstractTexture_setComparisonMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAbstractTexture_setLayers, "setLayers(self, layers: int)");

extern "C" {static PyObject *meth_Qt3DRender_QAbstractTexture_setLayers(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAbstractTexture_setLayers(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::Qt3DRender::QAbstractTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_Qt3DRender_QAbstractTexture, &sipCpp, &a0))
        {
            sipCpp->setLayers(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractTexture, sipName_setLayers, doc_Qt3DRender_QAbstractTexture_setLayers);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAbstractTexture_setSamples, "setSamples(self, samples: int)");

extern "C" {static PyObject *meth_Qt3DRender_QAbstractTexture_setSamples(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAbstractTexture_setSamples(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::Qt3DRender::QAbstractTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_Qt3DRender_QAbstractTexture, &sipCpp, &a0))
        {
            sipCpp->setSamples(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractTexture, sipName_setSamples, doc_Qt3DRender_QAbstractTexture_setSamples);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAbstractTexture_setStatus, "setStatus(self, status: QAbstractTexture.Status)");

extern "C" {static PyObject *meth_Qt3DRender_QAbstractTexture_setStatus(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAbstractTexture_setStatus(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QAbstractTexture::Status a0;
        ::Qt3DRender::QAbstractTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pE", &sipSelf, sipType_Qt3DRender_QAbstractTexture, &sipCpp, sipType_Qt3DRender_QAbstractTexture_Status, &a0))
        {
            sipCpp->setStatus(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractTexture, sipName_setStatus, doc_Qt3DRender_QAbstractTexture_setStatus);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAbstractTexture_sceneChangeEvent, "sceneChangeEvent(self, change: QSceneChange)");

extern "C" {static PyObject *meth_Qt3DRender_QAbstractTexture_sceneChangeEvent(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAbstractTexture_sceneChangeEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::Qt3DCore::QSceneChangePtr* a0;
        int a0State = 0;
        ::Qt3DRender::QAbstractTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ1", &sipSelf, sipType_Qt3DRender_QAbstractTexture, &sipCpp, sipType_QSharedPointer_0100Qt3DCore_QSceneChange, &a0, &a0State))
        {
            (sipSelfWasArg ? sipCpp->::Qt3DRender::QAbstractTexture::sceneChangeEvent(*a0) : sipCpp->sceneChangeEvent(*a0));
            sipReleaseType(const_cast< ::Qt3DCore::QSceneChangePtr *>(a0), sipType_QSharedPointer_0100Qt3DCore_QSceneChange, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractTexture, sipName_sceneChangeEvent, doc_Qt3DRender_QAbstractTexture_sceneChangeEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAbstractTexture_handleType, "handleType(self) -> QAbstractTexture.HandleType");

extern "C" {static PyObject *meth_Qt3DRender_QAbstractTexture_handleType(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAbstractTexture_handleType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QAbstractTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QAbstractTexture, &sipCpp))
        {
            ::Qt3DRender::QAbstractTexture::HandleType sipRes;

            sipRes = sipCpp->handleType();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QAbstractTexture_HandleType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractTexture, sipName_handleType, doc_Qt3DRender_QAbstractTexture_handleType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAbstractTexture_handle, "handle(self) -> Any");

extern "C" {static PyObject *meth_Qt3DRender_QAbstractTexture_handle(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAbstractTexture_handle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QAbstractTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QAbstractTexture, &sipCpp))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant(sipCpp->handle());

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractTexture, sipName_handle, doc_Qt3DRender_QAbstractTexture_handle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAbstractTexture_updateData, "updateData(self, update: QTextureDataUpdate)");

extern "C" {static PyObject *meth_Qt3DRender_QAbstractTexture_updateData(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAbstractTexture_updateData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QTextureDataUpdate* a0;
        ::Qt3DRender::QAbstractTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_Qt3DRender_QAbstractTexture, &sipCpp, sipType_Qt3DRender_QTextureDataUpdate, &a0))
        {
            sipCpp->updateData(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractTexture, sipName_updateData, doc_Qt3DRender_QAbstractTexture_updateData);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_Qt3DRender_QAbstractTexture(void *, const sipTypeDef *);}
static void *cast_Qt3DRender_QAbstractTexture(void *sipCppV, const sipTypeDef *targetType)
{
    ::Qt3DRender::QAbstractTexture *sipCpp = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(sipCppV);

    if (targetType == sipType_Qt3DRender_QAbstractTexture)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_Qt3DCore_QNode)->ctd_cast(static_cast< ::Qt3DCore::QNode *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_Qt3DRender_QAbstractTexture(void *, int);}
static void release_Qt3DRender_QAbstractTexture(void *sipCppV, int)
{
    ::Qt3DRender::QAbstractTexture *sipCpp = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_Qt3DRender_QAbstractTexture(Py_ssize_t);}
static void *array_Qt3DRender_QAbstractTexture(Py_ssize_t sipNrElem)
{
    return new ::Qt3DRender::QAbstractTexture[sipNrElem];
}


extern "C" {static void array_delete_Qt3DRender_QAbstractTexture(void *);}
static void array_delete_Qt3DRender_QAbstractTexture(void *sipCpp)
{
    delete[] reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(sipCpp);
}


extern "C" {static void dealloc_Qt3DRender_QAbstractTexture(sipSimpleWrapper *);}
static void dealloc_Qt3DRender_QAbstractTexture(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQt3DRender_QAbstractTexture *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_Qt3DRender_QAbstractTexture(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_Qt3DRender_QAbstractTexture(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_Qt3DRender_QAbstractTexture(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQt3DRender_QAbstractTexture *sipCpp = SIP_NULLPTR;

    {
        ::Qt3DCore::QNode* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_Qt3DCore_QNode, &a0, sipOwner))
        {
            sipCpp = new sipQt3DRender_QAbstractTexture(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::Qt3DRender::QAbstractTexture::Target a0;
        ::Qt3DCore::QNode* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "E|JH", sipType_Qt3DRender_QAbstractTexture_Target, &a0, sipType_Qt3DCore_QNode, &a1, sipOwner))
        {
            sipCpp = new sipQt3DRender_QAbstractTexture(a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_Qt3DRender_QAbstractTexture[] = {{4, 2, 1}};


static PyMethodDef methods_Qt3DRender_QAbstractTexture[] = {
    {sipName_addTextureImage, meth_Qt3DRender_QAbstractTexture_addTextureImage, METH_VARARGS, doc_Qt3DRender_QAbstractTexture_addTextureImage},
    {sipName_comparisonFunction, meth_Qt3DRender_QAbstractTexture_comparisonFunction, METH_VARARGS, doc_Qt3DRender_QAbstractTexture_comparisonFunction},
    {sipName_comparisonMode, meth_Qt3DRender_QAbstractTexture_comparisonMode, METH_VARARGS, doc_Qt3DRender_QAbstractTexture_comparisonMode},
    {sipName_dataGenerator, meth_Qt3DRender_QAbstractTexture_dataGenerator, METH_VARARGS, doc_Qt3DRender_QAbstractTexture_dataGenerator},
    {sipName_depth, meth_Qt3DRender_QAbstractTexture_depth, METH_VARARGS, doc_Qt3DRender_QAbstractTexture_depth},
    {sipName_format, meth_Qt3DRender_QAbstractTexture_format, METH_VARARGS, doc_Qt3DRender_QAbstractTexture_format},
    {sipName_generateMipMaps, meth_Qt3DRender_QAbstractTexture_generateMipMaps, METH_VARARGS, doc_Qt3DRender_QAbstractTexture_generateMipMaps},
    {sipName_handle, meth_Qt3DRender_QAbstractTexture_handle, METH_VARARGS, doc_Qt3DRender_QAbstractTexture_handle},
    {sipName_handleType, meth_Qt3DRender_QAbstractTexture_handleType, METH_VARARGS, doc_Qt3DRender_QAbstractTexture_handleType},
    {sipName_height, meth_Qt3DRender_QAbstractTexture_height, METH_VARARGS, doc_Qt3DRender_QAbstractTexture_height},
    {sipName_layers, meth_Qt3DRender_QAbstractTexture_layers, METH_VARARGS, doc_Qt3DRender_QAbstractTexture_layers},
    {sipName_magnificationFilter, meth_Qt3DRender_QAbstractTexture_magnificationFilter, METH_VARARGS, doc_Qt3DRender_QAbstractTexture_magnificationFilter},
    {sipName_maximumAnisotropy, meth_Qt3DRender_QAbstractTexture_maximumAnisotropy, METH_VARARGS, doc_Qt3DRender_QAbstractTexture_maximumAnisotropy},
    {sipName_minificationFilter, meth_Qt3DRender_QAbstractTexture_minificationFilter, METH_VARARGS, doc_Qt3DRender_QAbstractTexture_minificationFilter},
    {sipName_removeTextureImage, meth_Qt3DRender_QAbstractTexture_removeTextureImage, METH_VARARGS, doc_Qt3DRender_QAbstractTexture_removeTextureImage},
    {sipName_samples, meth_Qt3DRender_QAbstractTexture_samples, METH_VARARGS, doc_Qt3DRender_QAbstractTexture_samples},
    {sipName_sceneChangeEvent, meth_Qt3DRender_QAbstractTexture_sceneChangeEvent, METH_VARARGS, doc_Qt3DRender_QAbstractTexture_sceneChangeEvent},
    {sipName_setComparisonFunction, meth_Qt3DRender_QAbstractTexture_setComparisonFunction, METH_VARARGS, doc_Qt3DRender_QAbstractTexture_setComparisonFunction},
    {sipName_setComparisonMode, meth_Qt3DRender_QAbstractTexture_setComparisonMode, METH_VARARGS, doc_Qt3DRender_QAbstractTexture_setComparisonMode},
    {sipName_setDepth, meth_Qt3DRender_QAbstractTexture_setDepth, METH_VARARGS, doc_Qt3DRender_QAbstractTexture_setDepth},
    {sipName_setFormat, meth_Qt3DRender_QAbstractTexture_setFormat, METH_VARARGS, doc_Qt3DRender_QAbstractTexture_setFormat},
    {sipName_setGenerateMipMaps, meth_Qt3DRender_QAbstractTexture_setGenerateMipMaps, METH_VARARGS, doc_Qt3DRender_QAbstractTexture_setGenerateMipMaps},
    {sipName_setHeight, meth_Qt3DRender_QAbstractTexture_setHeight, METH_VARARGS, doc_Qt3DRender_QAbstractTexture_setHeight},
    {sipName_setLayers, meth_Qt3DRender_QAbstractTexture_setLayers, METH_VARARGS, doc_Qt3DRender_QAbstractTexture_setLayers},
    {sipName_setMagnificationFilter, meth_Qt3DRender_QAbstractTexture_setMagnificationFilter, METH_VARARGS, doc_Qt3DRender_QAbstractTexture_setMagnificationFilter},
    {sipName_setMaximumAnisotropy, meth_Qt3DRender_QAbstractTexture_setMaximumAnisotropy, METH_VARARGS, doc_Qt3DRender_QAbstractTexture_setMaximumAnisotropy},
    {sipName_setMinificationFilter, meth_Qt3DRender_QAbstractTexture_setMinificationFilter, METH_VARARGS, doc_Qt3DRender_QAbstractTexture_setMinificationFilter},
    {sipName_setSamples, meth_Qt3DRender_QAbstractTexture_setSamples, METH_VARARGS, doc_Qt3DRender_QAbstractTexture_setSamples},
    {sipName_setSize, SIP_MLMETH_CAST(meth_Qt3DRender_QAbstractTexture_setSize), METH_VARARGS|METH_KEYWORDS, doc_Qt3DRender_QAbstractTexture_setSize},
    {sipName_setStatus, meth_Qt3DRender_QAbstractTexture_setStatus, METH_VARARGS, doc_Qt3DRender_QAbstractTexture_setStatus},
    {sipName_setWidth, meth_Qt3DRender_QAbstractTexture_setWidth, METH_VARARGS, doc_Qt3DRender_QAbstractTexture_setWidth},
    {sipName_setWrapMode, meth_Qt3DRender_QAbstractTexture_setWrapMode, METH_VARARGS, doc_Qt3DRender_QAbstractTexture_setWrapMode},
    {sipName_status, meth_Qt3DRender_QAbstractTexture_status, METH_VARARGS, doc_Qt3DRender_QAbstractTexture_status},
    {sipName_target, meth_Qt3DRender_QAbstractTexture_target, METH_VARARGS, doc_Qt3DRender_QAbstractTexture_target},
    {sipName_textureImages, meth_Qt3DRender_QAbstractTexture_textureImages, METH_VARARGS, doc_Qt3DRender_QAbstractTexture_textureImages},
    {sipName_updateData, meth_Qt3DRender_QAbstractTexture_updateData, METH_VARARGS, doc_Qt3DRender_QAbstractTexture_updateData},
    {sipName_width, meth_Qt3DRender_QAbstractTexture_width, METH_VARARGS, doc_Qt3DRender_QAbstractTexture_width},
    {sipName_wrapMode, meth_Qt3DRender_QAbstractTexture_wrapMode, METH_VARARGS, doc_Qt3DRender_QAbstractTexture_wrapMode}
};

static sipEnumMemberDef enummembers_Qt3DRender_QAbstractTexture[] = {
    {sipName_AllFaces, static_cast<int>(::Qt3DRender::QAbstractTexture::AllFaces), 30},
    {sipName_AlphaFormat, static_cast<int>(::Qt3DRender::QAbstractTexture::AlphaFormat), 35},
    {sipName_Automatic, static_cast<int>(::Qt3DRender::QAbstractTexture::Automatic), 35},
    {sipName_CommpareNotEqual, static_cast<int>(::Qt3DRender::QAbstractTexture::CommpareNotEqual), 28},
    {sipName_CompareAlways, static_cast<int>(::Qt3DRender::QAbstractTexture::CompareAlways), 28},
    {sipName_CompareEqual, static_cast<int>(::Qt3DRender::QAbstractTexture::CompareEqual), 28},
    {sipName_CompareGreater, static_cast<int>(::Qt3DRender::QAbstractTexture::CompareGreater), 28},
    {sipName_CompareGreaterEqual, static_cast<int>(::Qt3DRender::QAbstractTexture::CompareGreaterEqual), 28},
    {sipName_CompareLess, static_cast<int>(::Qt3DRender::QAbstractTexture::CompareLess), 28},
    {sipName_CompareLessEqual, static_cast<int>(::Qt3DRender::QAbstractTexture::CompareLessEqual), 28},
    {sipName_CompareNever, static_cast<int>(::Qt3DRender::QAbstractTexture::CompareNever), 28},
    {sipName_CompareNone, static_cast<int>(::Qt3DRender::QAbstractTexture::CompareNone), 29},
    {sipName_CompareRefToTexture, static_cast<int>(::Qt3DRender::QAbstractTexture::CompareRefToTexture), 29},
    {sipName_CubeMapNegativeX, static_cast<int>(::Qt3DRender::QAbstractTexture::CubeMapNegativeX), 30},
    {sipName_CubeMapNegativeY, static_cast<int>(::Qt3DRender::QAbstractTexture::CubeMapNegativeY), 30},
    {sipName_CubeMapNegativeZ, static_cast<int>(::Qt3DRender::QAbstractTexture::CubeMapNegativeZ), 30},
    {sipName_CubeMapPositiveX, static_cast<int>(::Qt3DRender::QAbstractTexture::CubeMapPositiveX), 30},
    {sipName_CubeMapPositiveY, static_cast<int>(::Qt3DRender::QAbstractTexture::CubeMapPositiveY), 30},
    {sipName_CubeMapPositiveZ, static_cast<int>(::Qt3DRender::QAbstractTexture::CubeMapPositiveZ), 30},
    {sipName_D16, static_cast<int>(::Qt3DRender::QAbstractTexture::D16), 35},
    {sipName_D24, static_cast<int>(::Qt3DRender::QAbstractTexture::D24), 35},
    {sipName_D24S8, static_cast<int>(::Qt3DRender::QAbstractTexture::D24S8), 35},
    {sipName_D32, static_cast<int>(::Qt3DRender::QAbstractTexture::D32), 35},
    {sipName_D32F, static_cast<int>(::Qt3DRender::QAbstractTexture::D32F), 35},
    {sipName_D32FS8X24, static_cast<int>(::Qt3DRender::QAbstractTexture::D32FS8X24), 35},
    {sipName_DepthFormat, static_cast<int>(::Qt3DRender::QAbstractTexture::DepthFormat), 35},
    {sipName_Error, static_cast<int>(::Qt3DRender::QAbstractTexture::Error), 33},
    {sipName_Linear, static_cast<int>(::Qt3DRender::QAbstractTexture::Linear), 31},
    {sipName_LinearMipMapLinear, static_cast<int>(::Qt3DRender::QAbstractTexture::LinearMipMapLinear), 31},
    {sipName_LinearMipMapNearest, static_cast<int>(::Qt3DRender::QAbstractTexture::LinearMipMapNearest), 31},
    {sipName_Loading, static_cast<int>(::Qt3DRender::QAbstractTexture::Loading), 33},
    {sipName_LuminanceAlphaFormat, static_cast<int>(::Qt3DRender::QAbstractTexture::LuminanceAlphaFormat), 35},
    {sipName_LuminanceFormat, static_cast<int>(::Qt3DRender::QAbstractTexture::LuminanceFormat), 35},
    {sipName_Nearest, static_cast<int>(::Qt3DRender::QAbstractTexture::Nearest), 31},
    {sipName_NearestMipMapLinear, static_cast<int>(::Qt3DRender::QAbstractTexture::NearestMipMapLinear), 31},
    {sipName_NearestMipMapNearest, static_cast<int>(::Qt3DRender::QAbstractTexture::NearestMipMapNearest), 31},
    {sipName_NoFormat, static_cast<int>(::Qt3DRender::QAbstractTexture::NoFormat), 35},
    {sipName_NoHandle, static_cast<int>(::Qt3DRender::QAbstractTexture::NoHandle), 32},
    {sipName_None_, static_cast<int>(::Qt3DRender::QAbstractTexture::None), 33},
    {sipName_OpenGLTextureId, static_cast<int>(::Qt3DRender::QAbstractTexture::OpenGLTextureId), 32},
    {sipName_R11_EAC_SNorm, static_cast<int>(::Qt3DRender::QAbstractTexture::R11_EAC_SNorm), 35},
    {sipName_R11_EAC_UNorm, static_cast<int>(::Qt3DRender::QAbstractTexture::R11_EAC_UNorm), 35},
    {sipName_R16F, static_cast<int>(::Qt3DRender::QAbstractTexture::R16F), 35},
    {sipName_R16I, static_cast<int>(::Qt3DRender::QAbstractTexture::R16I), 35},
    {sipName_R16U, static_cast<int>(::Qt3DRender::QAbstractTexture::R16U), 35},
    {sipName_R16_SNorm, static_cast<int>(::Qt3DRender::QAbstractTexture::R16_SNorm), 35},
    {sipName_R16_UNorm, static_cast<int>(::Qt3DRender::QAbstractTexture::R16_UNorm), 35},
    {sipName_R32F, static_cast<int>(::Qt3DRender::QAbstractTexture::R32F), 35},
    {sipName_R32I, static_cast<int>(::Qt3DRender::QAbstractTexture::R32I), 35},
    {sipName_R32U, static_cast<int>(::Qt3DRender::QAbstractTexture::R32U), 35},
    {sipName_R5G6B5, static_cast<int>(::Qt3DRender::QAbstractTexture::R5G6B5), 35},
    {sipName_R8I, static_cast<int>(::Qt3DRender::QAbstractTexture::R8I), 35},
    {sipName_R8U, static_cast<int>(::Qt3DRender::QAbstractTexture::R8U), 35},
    {sipName_R8_SNorm, static_cast<int>(::Qt3DRender::QAbstractTexture::R8_SNorm), 35},
    {sipName_R8_UNorm, static_cast<int>(::Qt3DRender::QAbstractTexture::R8_UNorm), 35},
    {sipName_RG11B10F, static_cast<int>(::Qt3DRender::QAbstractTexture::RG11B10F), 35},
    {sipName_RG11_EAC_SNorm, static_cast<int>(::Qt3DRender::QAbstractTexture::RG11_EAC_SNorm), 35},
    {sipName_RG11_EAC_UNorm, static_cast<int>(::Qt3DRender::QAbstractTexture::RG11_EAC_UNorm), 35},
    {sipName_RG16F, static_cast<int>(::Qt3DRender::QAbstractTexture::RG16F), 35},
    {sipName_RG16I, static_cast<int>(::Qt3DRender::QAbstractTexture::RG16I), 35},
    {sipName_RG16U, static_cast<int>(::Qt3DRender::QAbstractTexture::RG16U), 35},
    {sipName_RG16_SNorm, static_cast<int>(::Qt3DRender::QAbstractTexture::RG16_SNorm), 35},
    {sipName_RG16_UNorm, static_cast<int>(::Qt3DRender::QAbstractTexture::RG16_UNorm), 35},
    {sipName_RG32F, static_cast<int>(::Qt3DRender::QAbstractTexture::RG32F), 35},
    {sipName_RG32I, static_cast<int>(::Qt3DRender::QAbstractTexture::RG32I), 35},
    {sipName_RG32U, static_cast<int>(::Qt3DRender::QAbstractTexture::RG32U), 35},
    {sipName_RG3B2, static_cast<int>(::Qt3DRender::QAbstractTexture::RG3B2), 35},
    {sipName_RG8I, static_cast<int>(::Qt3DRender::QAbstractTexture::RG8I), 35},
    {sipName_RG8U, static_cast<int>(::Qt3DRender::QAbstractTexture::RG8U), 35},
    {sipName_RG8_SNorm, static_cast<int>(::Qt3DRender::QAbstractTexture::RG8_SNorm), 35},
    {sipName_RG8_UNorm, static_cast<int>(::Qt3DRender::QAbstractTexture::RG8_UNorm), 35},
    {sipName_RGB10A2, static_cast<int>(::Qt3DRender::QAbstractTexture::RGB10A2), 35},
    {sipName_RGB10A2U, static_cast<int>(::Qt3DRender::QAbstractTexture::RGB10A2U), 35},
    {sipName_RGB16F, static_cast<int>(::Qt3DRender::QAbstractTexture::RGB16F), 35},
    {sipName_RGB16I, static_cast<int>(::Qt3DRender::QAbstractTexture::RGB16I), 35},
    {sipName_RGB16U, static_cast<int>(::Qt3DRender::QAbstractTexture::RGB16U), 35},
    {sipName_RGB16_SNorm, static_cast<int>(::Qt3DRender::QAbstractTexture::RGB16_SNorm), 35},
    {sipName_RGB16_UNorm, static_cast<int>(::Qt3DRender::QAbstractTexture::RGB16_UNorm), 35},
    {sipName_RGB32F, static_cast<int>(::Qt3DRender::QAbstractTexture::RGB32F), 35},
    {sipName_RGB32I, static_cast<int>(::Qt3DRender::QAbstractTexture::RGB32I), 35},
    {sipName_RGB32U, static_cast<int>(::Qt3DRender::QAbstractTexture::RGB32U), 35},
    {sipName_RGB5A1, static_cast<int>(::Qt3DRender::QAbstractTexture::RGB5A1), 35},
    {sipName_RGB8I, static_cast<int>(::Qt3DRender::QAbstractTexture::RGB8I), 35},
    {sipName_RGB8U, static_cast<int>(::Qt3DRender::QAbstractTexture::RGB8U), 35},
    {sipName_RGB8_ETC1, static_cast<int>(::Qt3DRender::QAbstractTexture::RGB8_ETC1), 35},
    {sipName_RGB8_ETC2, static_cast<int>(::Qt3DRender::QAbstractTexture::RGB8_ETC2), 35},
    {sipName_RGB8_PunchThrough_Alpha1_ETC2, static_cast<int>(::Qt3DRender::QAbstractTexture::RGB8_PunchThrough_Alpha1_ETC2), 35},
    {sipName_RGB8_SNorm, static_cast<int>(::Qt3DRender::QAbstractTexture::RGB8_SNorm), 35},
    {sipName_RGB8_UNorm, static_cast<int>(::Qt3DRender::QAbstractTexture::RGB8_UNorm), 35},
    {sipName_RGB9E5, static_cast<int>(::Qt3DRender::QAbstractTexture::RGB9E5), 35},
    {sipName_RGBA16F, static_cast<int>(::Qt3DRender::QAbstractTexture::RGBA16F), 35},
    {sipName_RGBA16I, static_cast<int>(::Qt3DRender::QAbstractTexture::RGBA16I), 35},
    {sipName_RGBA16U, static_cast<int>(::Qt3DRender::QAbstractTexture::RGBA16U), 35},
    {sipName_RGBA16_SNorm, static_cast<int>(::Qt3DRender::QAbstractTexture::RGBA16_SNorm), 35},
    {sipName_RGBA16_UNorm, static_cast<int>(::Qt3DRender::QAbstractTexture::RGBA16_UNorm), 35},
    {sipName_RGBA32F, static_cast<int>(::Qt3DRender::QAbstractTexture::RGBA32F), 35},
    {sipName_RGBA32I, static_cast<int>(::Qt3DRender::QAbstractTexture::RGBA32I), 35},
    {sipName_RGBA32U, static_cast<int>(::Qt3DRender::QAbstractTexture::RGBA32U), 35},
    {sipName_RGBA4, static_cast<int>(::Qt3DRender::QAbstractTexture::RGBA4), 35},
    {sipName_RGBA8I, static_cast<int>(::Qt3DRender::QAbstractTexture::RGBA8I), 35},
    {sipName_RGBA8U, static_cast<int>(::Qt3DRender::QAbstractTexture::RGBA8U), 35},
    {sipName_RGBA8_ETC2_EAC, static_cast<int>(::Qt3DRender::QAbstractTexture::RGBA8_ETC2_EAC), 35},
    {sipName_RGBA8_SNorm, static_cast<int>(::Qt3DRender::QAbstractTexture::RGBA8_SNorm), 35},
    {sipName_RGBA8_UNorm, static_cast<int>(::Qt3DRender::QAbstractTexture::RGBA8_UNorm), 35},
    {sipName_RGBAFormat, static_cast<int>(::Qt3DRender::QAbstractTexture::RGBAFormat), 35},
    {sipName_RGBA_DXT1, static_cast<int>(::Qt3DRender::QAbstractTexture::RGBA_DXT1), 35},
    {sipName_RGBA_DXT3, static_cast<int>(::Qt3DRender::QAbstractTexture::RGBA_DXT3), 35},
    {sipName_RGBA_DXT5, static_cast<int>(::Qt3DRender::QAbstractTexture::RGBA_DXT5), 35},
    {sipName_RGBFormat, static_cast<int>(::Qt3DRender::QAbstractTexture::RGBFormat), 35},
    {sipName_RGB_BP_SIGNED_FLOAT, static_cast<int>(::Qt3DRender::QAbstractTexture::RGB_BP_SIGNED_FLOAT), 35},
    {sipName_RGB_BP_UNSIGNED_FLOAT, static_cast<int>(::Qt3DRender::QAbstractTexture::RGB_BP_UNSIGNED_FLOAT), 35},
    {sipName_RGB_BP_UNorm, static_cast<int>(::Qt3DRender::QAbstractTexture::RGB_BP_UNorm), 35},
    {sipName_RGB_DXT1, static_cast<int>(::Qt3DRender::QAbstractTexture::RGB_DXT1), 35},
    {sipName_RG_ATI2N_SNorm, static_cast<int>(::Qt3DRender::QAbstractTexture::RG_ATI2N_SNorm), 35},
    {sipName_RG_ATI2N_UNorm, static_cast<int>(::Qt3DRender::QAbstractTexture::RG_ATI2N_UNorm), 35},
    {sipName_R_ATI1N_SNorm, static_cast<int>(::Qt3DRender::QAbstractTexture::R_ATI1N_SNorm), 35},
    {sipName_R_ATI1N_UNorm, static_cast<int>(::Qt3DRender::QAbstractTexture::R_ATI1N_UNorm), 35},
    {sipName_Ready, static_cast<int>(::Qt3DRender::QAbstractTexture::Ready), 33},
    {sipName_SRGB8, static_cast<int>(::Qt3DRender::QAbstractTexture::SRGB8), 35},
    {sipName_SRGB8_Alpha8, static_cast<int>(::Qt3DRender::QAbstractTexture::SRGB8_Alpha8), 35},
    {sipName_SRGB8_Alpha8_ETC2_EAC, static_cast<int>(::Qt3DRender::QAbstractTexture::SRGB8_Alpha8_ETC2_EAC), 35},
    {sipName_SRGB8_ETC2, static_cast<int>(::Qt3DRender::QAbstractTexture::SRGB8_ETC2), 35},
    {sipName_SRGB8_PunchThrough_Alpha1_ETC2, static_cast<int>(::Qt3DRender::QAbstractTexture::SRGB8_PunchThrough_Alpha1_ETC2), 35},
    {sipName_SRGB_Alpha_DXT1, static_cast<int>(::Qt3DRender::QAbstractTexture::SRGB_Alpha_DXT1), 35},
    {sipName_SRGB_Alpha_DXT3, static_cast<int>(::Qt3DRender::QAbstractTexture::SRGB_Alpha_DXT3), 35},
    {sipName_SRGB_Alpha_DXT5, static_cast<int>(::Qt3DRender::QAbstractTexture::SRGB_Alpha_DXT5), 35},
    {sipName_SRGB_BP_UNorm, static_cast<int>(::Qt3DRender::QAbstractTexture::SRGB_BP_UNorm), 35},
    {sipName_SRGB_DXT1, static_cast<int>(::Qt3DRender::QAbstractTexture::SRGB_DXT1), 35},
    {sipName_Target1D, static_cast<int>(::Qt3DRender::QAbstractTexture::Target1D), 34},
    {sipName_Target1DArray, static_cast<int>(::Qt3DRender::QAbstractTexture::Target1DArray), 34},
    {sipName_Target2D, static_cast<int>(::Qt3DRender::QAbstractTexture::Target2D), 34},
    {sipName_Target2DArray, static_cast<int>(::Qt3DRender::QAbstractTexture::Target2DArray), 34},
    {sipName_Target2DMultisample, static_cast<int>(::Qt3DRender::QAbstractTexture::Target2DMultisample), 34},
    {sipName_Target2DMultisampleArray, static_cast<int>(::Qt3DRender::QAbstractTexture::Target2DMultisampleArray), 34},
    {sipName_Target3D, static_cast<int>(::Qt3DRender::QAbstractTexture::Target3D), 34},
    {sipName_TargetAutomatic, static_cast<int>(::Qt3DRender::QAbstractTexture::TargetAutomatic), 34},
    {sipName_TargetBuffer, static_cast<int>(::Qt3DRender::QAbstractTexture::TargetBuffer), 34},
    {sipName_TargetCubeMap, static_cast<int>(::Qt3DRender::QAbstractTexture::TargetCubeMap), 34},
    {sipName_TargetCubeMapArray, static_cast<int>(::Qt3DRender::QAbstractTexture::TargetCubeMapArray), 34},
    {sipName_TargetRectangle, static_cast<int>(::Qt3DRender::QAbstractTexture::TargetRectangle), 34},
};

PyDoc_STRVAR(doc_Qt3DRender_QAbstractTexture, "\1QAbstractTexture(parent: QNode|None = None)\n"
"QAbstractTexture(target: QAbstractTexture.Target, parent: QNode|None = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_Qt3DRender_QAbstractTexture[] = {
    {"handleChanged(QVariant)", "\1handleChanged(self, handle: Any)", SIP_NULLPTR, SIP_NULLPTR},
    {"handleTypeChanged(Qt3DRender::QAbstractTexture::HandleType)", "\1handleTypeChanged(self, handleType: QAbstractTexture.HandleType)", SIP_NULLPTR, SIP_NULLPTR},
    {"samplesChanged(int)", "\1samplesChanged(self, samples: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"layersChanged(int)", "\1layersChanged(self, layers: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"comparisonModeChanged(ComparisonMode)|(Qt3DRender::QAbstractTexture::ComparisonMode)", "\1comparisonModeChanged(self, comparisonMode: QAbstractTexture.ComparisonMode)", SIP_NULLPTR, SIP_NULLPTR},
    {"comparisonFunctionChanged(ComparisonFunction)|(Qt3DRender::QAbstractTexture::ComparisonFunction)", "\1comparisonFunctionChanged(self, comparisonFunction: QAbstractTexture.ComparisonFunction)", SIP_NULLPTR, SIP_NULLPTR},
    {"maximumAnisotropyChanged(float)", "\1maximumAnisotropyChanged(self, maximumAnisotropy: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"minificationFilterChanged(Filter)|(Qt3DRender::QAbstractTexture::Filter)", "\1minificationFilterChanged(self, minificationFilter: QAbstractTexture.Filter)", SIP_NULLPTR, SIP_NULLPTR},
    {"magnificationFilterChanged(Filter)|(Qt3DRender::QAbstractTexture::Filter)", "\1magnificationFilterChanged(self, magnificationFilter: QAbstractTexture.Filter)", SIP_NULLPTR, SIP_NULLPTR},
    {"depthChanged(int)", "\1depthChanged(self, depth: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"heightChanged(int)", "\1heightChanged(self, height: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"widthChanged(int)", "\1widthChanged(self, width: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"generateMipMapsChanged(bool)", "\1generateMipMapsChanged(self, generateMipMaps: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"statusChanged(Status)|(Qt3DRender::QAbstractTexture::Status)", "\1statusChanged(self, status: QAbstractTexture.Status)", SIP_NULLPTR, SIP_NULLPTR},
    {"formatChanged(TextureFormat)|(Qt3DRender::QAbstractTexture::TextureFormat)", "\1formatChanged(self, format: QAbstractTexture.TextureFormat)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_Qt3DRender_QAbstractTexture = {
    &::Qt3DRender::QAbstractTexture::staticMetaObject,
    0,
    signals_Qt3DRender_QAbstractTexture,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QAbstractTexture = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_Qt3DRender__QAbstractTexture,
        SIP_NULLPTR,
        &plugin_Qt3DRender_QAbstractTexture,
    },
    {
        sipNameNr_QAbstractTexture,
        {0, 0, 1},
        38, methods_Qt3DRender_QAbstractTexture,
        140, enummembers_Qt3DRender_QAbstractTexture,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_Qt3DRender_QAbstractTexture,
    -1,
    -1,
    supers_Qt3DRender_QAbstractTexture,
    SIP_NULLPTR,
    init_type_Qt3DRender_QAbstractTexture,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_Qt3DRender_QAbstractTexture,
    SIP_NULLPTR,
    array_Qt3DRender_QAbstractTexture,
    SIP_NULLPTR,
    release_Qt3DRender_QAbstractTexture,
    cast_Qt3DRender_QAbstractTexture,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_Qt3DRender_QAbstractTexture,
    sizeof (::Qt3DRender::QAbstractTexture),
};
